@@ -29,7 +29,7 @@
 #include "pyginterface.h"
 #include "pygparamspec.h"
 
-#include "pygi-external.h"
+#include "pygi.h"
 
 
 static void pygobject_dealloc(PyGObject *self);
@@ -112,6 +112,13 @@ pygobject_get_inst_data(PyGObject *self)
     return inst_data;
 }
 
+
+typedef struct {
+    GType type;
+    void (* sinkfunc)(GObject *object);
+} SinkFunc;
+static GArray *sink_funcs = NULL;
+
 GHashTable *custom_type_registration = NULL;
 
 PyTypeObject *PyGObject_MetaType = NULL;
@@ -128,7 +135,23 @@ PyTypeObject *PyGObject_MetaType = NULL;
 void
 pygobject_sink(GObject *obj)
 {
-    if (G_IS_INITIALLY_UNOWNED(obj) || g_object_is_floating(obj)) {
+    if (sink_funcs) {
+	gint i;
+
+	for (i = 0; i < sink_funcs->len; i++) {
+	    if (g_type_is_a(G_OBJECT_TYPE(obj),
+			    g_array_index(sink_funcs, SinkFunc, i).type)) {
+		g_array_index(sink_funcs, SinkFunc, i).sinkfunc(obj);
+		return;
+	    }
+	}
+    }
+    if (G_IS_INITIALLY_UNOWNED(obj) && !g_object_is_floating(obj)) {
+        /* GtkWindow and GtkInvisible does not return a ref to caller of
+         * g_object_new.
+         */
+        g_object_ref(obj);
+    } else if (g_object_is_floating(obj)) {
         g_object_ref_sink(obj);
     }
 }
@@ -146,12 +169,27 @@ pygobject_sink(GObject *obj)
  * The sinkfunc should be able to remove the floating reference on
  * instances of the given type, or any subclasses.
  *
- * Deprecated: Since 2.20, sinkfuncs are not needed.
+ * Deprecated: Since 2.22, sinkfuncs are not needed.
  */
 void
 pygobject_register_sinkfunc(GType type, void (* sinkfunc)(GObject *object))
 {
+    SinkFunc sf;
 
+    g_message ("pygobject_register_sinkfunc is deprecated (%s)",
+               g_type_name(type));
+
+#if 0
+    g_return_if_fail(G_TYPE_IS_OBJECT(type));
+#endif
+    g_return_if_fail(sinkfunc != NULL);
+    
+    if (!sink_funcs)
+	sink_funcs = g_array_new(FALSE, FALSE, sizeof(SinkFunc));
+
+    sf.type = type;
+    sf.sinkfunc = sinkfunc;
+    g_array_append_val(sink_funcs, sf);
 }
 
 typedef struct {
@@ -269,7 +307,9 @@ PyGProps_getattro(PyGProps *self, PyObject *attr)
     }
     
     g_value_init(&value, G_PARAM_SPEC_VALUE_TYPE(pspec));
+    pyg_begin_allow_threads;
     g_object_get_property(self->pygobject->obj, attr_name, &value);
+    pyg_end_allow_threads;
     ret = pyg_param_gvalue_as_pyobject(&value, TRUE, pspec);
     g_value_unset(&value);
     
@@ -561,29 +601,28 @@ pygobject_switch_to_toggle_ref(PyGObject *self)
 /**
  * pygobject_register_wrapper:
  * @self: the wrapper instance
- * @sink: whether to sink self. DEPRECATED
  *
  * In the constructor of PyGTK wrappers, this function should be
  * called after setting the obj member.  It will tie the wrapper
  * instance to the GObject so that the same wrapper instance will
  * always be used for this GObject instance.
  */
-static inline void
-pygobject_register_wrapper_full(PyGObject *self, gboolean sink)
-{
-    GObject *obj = self->obj;
-
-    g_assert(obj->ref_count >= 1);
-      /* save wrapper pointer so we can access it later */
-    g_object_set_qdata_full(obj, pygobject_wrapper_key, self, NULL);
-    if (self->inst_dict)
-        pygobject_switch_to_toggle_ref(self);
-}
-
 void
 pygobject_register_wrapper(PyObject *self)
 {
-    pygobject_register_wrapper_full((PyGObject *)self, TRUE);
+    PyGObject *gself;
+
+    g_return_if_fail(self != NULL);
+    g_return_if_fail(PyObject_TypeCheck(self, &PyGObject_Type));
+
+    gself = (PyGObject *)self;
+
+    pygobject_sink(gself->obj);
+    g_assert(gself->obj->ref_count >= 1);
+      /* save wrapper pointer so we can access it later */
+    g_object_set_qdata_full(gself->obj, pygobject_wrapper_key, gself, NULL);
+    if (gself->inst_dict)
+        pygobject_switch_to_toggle_ref(gself);
 }
 
 static PyObject *
@@ -912,8 +951,7 @@ pygobject_new_full(GObject *obj, gboolean sink, gpointer g_class)
 	self->private_flags.flags = 0;
 	self->obj = obj;
 	g_object_ref(obj);
-	pygobject_register_wrapper_full(self, sink);
-	pygobject_sink(obj);    
+	pygobject_register_wrapper((PyObject *)self);
 	PyObject_GC_Track((PyObject *)self);
     }
 
@@ -1048,8 +1086,11 @@ pygobject_clear(PyGObject *self)
         if (self->inst_dict) {
             g_object_remove_toggle_ref(self->obj, pyg_toggle_notify, self);
             self->private_flags.flags &= ~PYGOBJECT_USING_TOGGLE_REF;
-        } else
+        } else {
+            pyg_begin_allow_threads;
             g_object_unref(self->obj);
+            pyg_end_allow_threads;
+        }
         self->obj = NULL;
     }
     Py_CLEAR(self->inst_dict);
@@ -1179,7 +1220,9 @@ pygobject_get_property(PyGObject *self, PyObject *args)
 	return NULL;
     }
     g_value_init(&value, G_PARAM_SPEC_VALUE_TYPE(pspec));
+    pyg_begin_allow_threads;
     g_object_get_property(self->obj, param_name, &value);
+    pyg_end_allow_threads;
     ret = pyg_param_gvalue_as_pyobject(&value, TRUE, pspec);
     g_value_unset(&value);
     return ret;
@@ -1229,7 +1272,9 @@ pygobject_get_properties(PyGObject *self, PyObject *args)
         }
         g_value_init(&value, G_PARAM_SPEC_VALUE_TYPE(pspec));
 
+        pyg_begin_allow_threads;
         g_object_get_property(self->obj, property_name, &value);
+        pyg_end_allow_threads;
 
         item = pyg_value_as_pyobject(&value, TRUE);
         PyTuple_SetItem(tuple, i, item);
