@@ -1,28 +1,24 @@
 import os
 import sys
 
-def importModules(buildDir, srcDir):
+def importModules(buildDir):
     # Be very careful when you change this code, it's
     # fragile and the order is really significant
 
-    # ltihooks
-    sys.path.insert(0, srcDir)
     sys.path.insert(0, buildDir)
+    sys.path.insert(0, os.path.join(buildDir, 'glib'))
     sys.path.insert(0, os.path.join(buildDir, 'gobject'))
     sys.path.insert(0, os.path.join(buildDir, 'gio'))
-    import ltihooks
 
     # testhelper
     sys.path.insert(0, os.path.join(buildDir, 'tests'))
     sys.argv.append('--g-fatal-warnings')
 
     testhelper = importModule('testhelper', '.')
+    glib = importModule('glib', buildDir, 'glib')
     gobject = importModule('gobject', buildDir, 'gobject')
     gio = importModule('gio', buildDir, 'gio')
 
-    ltihooks.uninstall()
-    del ltihooks
-
     globals().update(locals())
 
     os.environ['PYGTK_USE_GIL_STATE_API'] = ''
@@ -40,11 +36,7 @@ def importModule(module, directory, name=None):
     except ImportError, e:
         raise SystemExit('%s could not be imported: %s' % (origName, e))
 
-    if hasattr(obj, '__file__'):
-        location = obj.__file__
-    else:
-        package = __import__(fromlist)
-        location = os.path.join(package.__file__, name)
+    location = obj.__file__
 
     current = os.getcwd()
     expected = os.path.abspath(os.path.join(current, location))
